@@ -76,7 +76,6 @@ class Requestant(httping.Parsent):
         self.path = u''  # partial path in request line without scheme host port query fragment
         self.query = u'' # query string from full path
         self.fragment = u''  # fragment from full path
-        self.changed = False  # True if msg changed on last parse iteration
 
     def checkPersisted(self):
         """
@@ -626,13 +625,6 @@ class Valet(object):
                     break
         return idle
 
-    def refreshIx(self, ca):
-        """
-        Restart incomer timer given by ca
-        """
-        if ca in self.ixes:
-            self.ixes[ca].timer.restart()
-
     def buildEnviron(self, requestant):
         """
         Returns wisgi environment dictionary for supplied requestant
@@ -718,9 +710,6 @@ class Valet(object):
                     self.closeConnection(ca)
                     continue
 
-                if requestant.changed:
-                    self.refreshIx(ca)
-
                 if requestant.ended:
                     console.concise("Parsed Request:\n{0} {1} {2}\n"
                                     "{3}\n{4}\n".format(requestant.method,
@@ -1121,9 +1110,6 @@ class Porter(object):
             if not steward.waited:
                 steward.requestant.parse()
 
-                if steward.requestant.changed:
-                    steward.refresh()
-
                 if steward.requestant.ended:
                     steward.requestant.dictify()
                     console.concise("Parsed Request:\n{0} {1} {2}\n"
